@@ -32,10 +32,6 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
-import six
-
 import github.CommitCombinedStatus
 import github.CommitComment
 import github.CommitStats
@@ -150,15 +146,11 @@ class Commit(github.GithubObject.CompletableGithubObject):
         :param position: integer
         :rtype: :class:`github.CommitComment.CommitComment`
         """
-        assert isinstance(body, (str, six.text_type)), body
-        assert line is github.GithubObject.NotSet or isinstance(
-            line, six.integer_types
-        ), line
-        assert path is github.GithubObject.NotSet or isinstance(
-            path, (str, six.text_type)
-        ), path
+        assert isinstance(body, str), body
+        assert line is github.GithubObject.NotSet or isinstance(line, int), line
+        assert path is github.GithubObject.NotSet or isinstance(path, str), path
         assert position is github.GithubObject.NotSet or isinstance(
-            position, six.integer_types
+            position, int
         ), position
         post_parameters = {
             "body": body,
@@ -191,15 +183,15 @@ class Commit(github.GithubObject.CompletableGithubObject):
         :param context: string
         :rtype: :class:`github.CommitStatus.CommitStatus`
         """
-        assert isinstance(state, (str, six.text_type)), state
+        assert isinstance(state, str), state
         assert target_url is github.GithubObject.NotSet or isinstance(
-            target_url, (str, six.text_type)
+            target_url, str
         ), target_url
         assert description is github.GithubObject.NotSet or isinstance(
-            description, (str, six.text_type)
+            description, str
         ), description
         assert context is github.GithubObject.NotSet or isinstance(
-            context, (str, six.text_type)
+            context, str
         ), context
         post_parameters = {
             "state": state,
