@@ -35,12 +35,8 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
 from os.path import basename
 
-import six
-
 import github.GithubObject
 import github.GitReleaseAsset
 import github.NamedUser
@@ -195,13 +191,13 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.GitRelease.GitRelease`
         """
         assert tag_name is github.GithubObject.NotSet or isinstance(
-            tag_name, (str, six.text_type)
+            tag_name, str
         ), "tag_name must be a str/unicode object"
         assert target_commitish is github.GithubObject.NotSet or isinstance(
-            target_commitish, (str, six.text_type)
+            target_commitish, str
         ), "target_commitish must be a str/unicode object"
-        assert isinstance(name, (str, six.text_type)), name
-        assert isinstance(message, (str, six.text_type)), message
+        assert isinstance(name, str), name
+        assert isinstance(message, str), message
         assert isinstance(draft, bool), draft
         assert isinstance(prerelease, bool), prerelease
         if tag_name is github.GithubObject.NotSet:
@@ -235,11 +231,9 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         :calls: `POST https://<upload_url>/repos/:owner/:repo/releases/:release_id/assets <https://developer.github.com/v3/repos/releases/#upload-a-release-asset>`_
         :rtype: :class:`github.GitReleaseAsset.GitReleaseAsset`
         """
-        assert isinstance(path, (str, six.text_type)), path
-        assert isinstance(label, (str, six.text_type)), label
-        assert name is github.GithubObject.NotSet or isinstance(
-            name, (str, six.text_type)
-        ), name
+        assert isinstance(path, str), path
+        assert isinstance(label, str), label
+        assert name is github.GithubObject.NotSet or isinstance(name, str), name
 
         post_parameters = {"label": label}
         if name is github.GithubObject.NotSet:
