@@ -22,10 +22,10 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
 import github.GithubObject
 
+from . import Consts
+
 # NOTE: There is currently no way to get cards "in triage" for a project.
 # https://platform.github.community/t/moving-github-project-cards-that-are-in-triage/3784
 #
@@ -117,23 +117,50 @@ class ProjectCard(github.GithubObject.CompletableGithubObject):
     def get_content(self, content_type=github.GithubObject.NotSet):
         """
         :calls: `GET /repos/:owner/:repo/pulls/:number <https://developer.github.com/v3/pulls/#get-a-single-pull-request>`_
+        :param content_type: string, optional
         :rtype: :class:`github.PullRequest.PullRequest` or :class:`github.Issue.Issue`
         """
+        assert content_type is github.GithubObject.NotSet or isinstance(
+            content_type, str
+        ), content_type
         if self.content_url is None:
             return None
 
         if content_type == "PullRequest":
-            headers, data = self._requester.requestJsonAndCheck(
-                "GET", self.content_url.replace("issues", "pulls")
-            )
-            return github.PullRequest.PullRequest(
-                self._requester, headers, data, completed=True
-            )
+            url = self.content_url.replace("issues", "pulls")
+            retclass = github.PullRequest.PullRequest
         elif content_type is github.GithubObject.NotSet or content_type == "Issue":
-            headers, data = self._requester.requestJsonAndCheck("GET", self.content_url)
-            return github.Issue.Issue(self._requester, headers, data, completed=True)
+            url = self.content_url
+            retclass = github.Issue.Issue
         else:
-            assert False, "Unknown content type: %s" % content_type
+            raise ValueError("Unknown content type: %s" % content_type)
+        headers, data = self._requester.requestJsonAndCheck("GET", url)
+        return retclass(self._requester, headers, data, completed=True)
+
+    def move(self, position, column):
+        """
+        :calls: `POST /projects/columns/cards/:card_id/moves <https://developer.github.com/v3/projects/cards>`_
+        :param position: string
+        :param column: :class:`github.ProjectColumn.ProjectColumn` or int
+        :rtype: bool
+        """
+        assert isinstance(position, str), position
+        assert isinstance(column, github.ProjectColumn.ProjectColumn) or isinstance(
+            column, int
+        ), column
+        post_parameters = {
+            "position": position,
+            "column": column.id
+            if isinstance(column, github.ProjectColumn.ProjectColumn)
+            else column,
+        }
+        status, _, _ = self._requester.requestJson(
+            "POST",
+            self.url + "/moves",
+            input=post_parameters,
+            headers={"Accept": Consts.mediaTypeProjectsPreview},
+        )
+        return status == 201
 
     def _initAttributes(self):
         self._archived = github.GithubObject.NotSet
